class GridCoonstant:
    refresh_production_order_grid = "refresh_production_order_grid"
    refresh_production_order_grid_row = "refresh_production_order_grid_row"

    refresh_operationsGrid = "operationsGrid"
    refresh_operationsGrid_row = "operationsGridRow"

    refresh_production_order_item_grid = "refresh_production_order_item_grid"
    refresh_production_order_item_grid_row = "refresh_production_order_item_gridRow"

    refresh_production_operations_grid = "refresh_production_operations_grid"
    refresh_production_operations_grid_row = "refresh_production_operations_grid_grid_row"

    refresh_production_order_operationsValues_grid = "refresh_production_order_operationsValues_grid"
    refresh_production_order_operationsValues_grid_row = "refresh_production_order_operationsValues_grid_row"

    refresh_production_launch_grid = "refresh_production_launch_grid"
    refresh_production_launch_grid_row = "refresh_production_launch_grid_row"

    refresh_production_buffers_grid = "refresh_production_buffers_grid"
    refresh_production_buffers_grid_row = "refresh_production_buffers_grid_row"

    refresh_item_view_grid = "refresh_item_view_grid"
    refresh_item_view_grid_row = "refresh_item_view_grid_row"

    tmp_operation_value_view_grid = "tmp_operation_value_view_grid"
    tmp_operation_value_view_grid_row = "tmp_operation_value_view_grid_row"

    lock_insert_update_delete_function_of_table = "lock_insert_update_delete_function_of_table"
